//
//  SetCard.swift
//  Set
//
//  Created by Sameh Fakhouri on 10/13/21.
//

import Foundation


struct SetCard : Identifiable, Equatable {
    
    static func ==(lhs: SetCard, rhs: SetCard) -> Bool {
        return (lhs.shape == rhs.shape &&
                    lhs.shade == rhs.shade &&
                    lhs.color == rhs.color &&
                    lhs.count == rhs.count &&
                    lhs.id == rhs.id)
    }
    
    var shape: Shapes
    var shade: Shades
    var color: Colors
    var count: Int
    var id: Int

    var isSelected: Bool
    var isMatched: Bool
    var isMisMatched: Bool
    
    enum Shapes {
        case circle
        case square
        case triangle
        
        static var all = [Shapes.circle, .square, .triangle]
    }
    
    enum Shades {
        case outlined
        case shaded
        case filled
        
        static var all = [Shades.outlined, .shaded, .filled]
    }
    
    enum Colors {
        case red
        case green
        case purple
        
        static var all = [Colors.red, .green, .purple]
    }

    init(shape: Shapes, shade: Shades, color: Colors, count: Int, id: Int ) {
        self.shape = shape
        self.shade = shade
        self.color = color
        self.count = count
        self.id = id
        self.isSelected = false
        self.isMatched = false
        self.isMisMatched = false
    }

    func getCardContents() -> String {
        var shape: String
        
        if self.shade == .outlined {
            switch self.shape {
            case .square:
                shape = "◻︎"
            case .circle:
                shape = "○"
            case .triangle:
                shape = "△"
            }
        } else {
            switch self.shape {
            case .square:
                shape = "◼︎"
            case .circle:
                shape = "●"
            case .triangle:
                shape = "▲"
            }
        }
        
        var cardEmojis = ""
        
        for _ in 1...self.count {
            cardEmojis += shape
        }
        
        return cardEmojis
    }
}
